@@ -1,3 +1,4 @@
+# cython: language_level=3
 import pyvisa
 import serial
 import time
@@ -224,6 +225,7 @@ class at_communication_pack():
 
     
 if __name__=="__main__":
+    pass
     # comK = [3,5,8]
     # vss = [at_communication_pack() for idx in range(len(comK))]
     # [vss[idx]._connect(str(idx)) for idx in range(len(comK))]
@@ -233,21 +235,21 @@ if __name__=="__main__":
     # vss._send_and_recv_confirm_single_key("AT+SIMCOMATI","OK")
     # vss._send_and_recv_confirm_multiple_key("AT+SIMCOMATI",["A011B02A7670M6","OK"])
     # InThreadTime.Sleep(10)
-    xe = scpi_cmw500_test_cmd()
+    #xe = scpi_cmw500_test_cmd()
     # xe._connect("GPIB0::20::INSTR")
     # xe.Mes2GInit()
     # xe.Mes2GOn()
     # print(xe.TxPower2GGet())
     # xe = scpi_SP9500_test_cmd()
-    xe._connect("TCPIP0::192.168.1.9::inst0::INSTR")
+    #xe._connect("TCPIP0::192.168.1.9::inst0::INSTR")
     # xe.Init_Instr()
     # xe.HandOver_regist_Init_Catm()
     # xe.Instr_SIGN_ON()
-    xe.HandOver_to_other_Band_Catm("2")
-    time.sleep(2)
-    xe.HandOver_Init_Catm()
-    data=xe.HandOver_QueryTxPowerAVERage()
-    print(data)
+    #xe.HandOver_to_other_Band_Catm("2")
+    #time.sleep(2)
+    #xe.HandOver_Init_Catm()
+    #data=xe.HandOver_QueryTxPowerAVERage()
+    #print(data)
 
     # xe._connect("TCPIP0::192.168.1.80::inst0::INSTR")
     # xe.MesureInitV2()
