@@ -38,6 +38,7 @@ if __name__=="__main__":
     # path = ["cnblogs","com","hardfood"]
     # Ini.Write(path[0],path[1],path[2])
     # print("{}.{}/{}".format(path[0],path[1],Ini.Read(path[0],path[1])))
-    data= Ini.Read("Instr","B{}-BW".format(1),"10")
-    print(data)
-    print(int(data[1]))
\ No newline at end of file
+    #data= Ini.Read("Instr","B{}-BW".format(1),"10")
+    #print(data)
+    #print(int(data[1]))
+    pass
